import { injectScripts, checkAllObjectValuesAreTrue } from "../../scriptInjector"

let hasBeenLoaded = false

/**
 * Loads TwitterBootstrap from CDN
 * 
 * Usage:
	import twitterBootstrapLoader from 'hs-dev-helper/js-toolkit/cdnLoaders/twitterBootstrapJs/twitterBootstrapJsLoader'
	(async () => await twitterBootstrapLoader.loadTwitterBootstrapJsScripts())()
 */
export const loader = class {

	twitterBootstrapJs = {
		ready : false,
		loaded: {
			script: false
		}
	}

	loadTwitterBootstrapJsScripts = (onload = null) => { 
		return new Promise((res, rej) => {

			const checkIfAllAreLoaded = () => {
				this.twitterBootstrapJs.ready = checkAllObjectValuesAreTrue(this.twitterBootstrapJs.loaded)
				if (this.twitterBootstrapJs.ready) {
					let payload = {bootstrap: window.bootstrap}
					// Fire Event
					var event = new CustomEvent('TwitterBootstrapLoaded', { detail : payload });
					window.dispatchEvent(event);
					// OnLoad Callback
					if (this.twitterBootstrapJs.loaded.script && !!onload && typeof onload == 'function') { 
						onload(payload)
					}
					// Flag
					hasBeenLoaded = true
					// Return Promise
					res(payload)
				}
			}
			
			let scripts = [
				{
					type: 'script',
					src: 'https://cdn.jsdelivr.net/npm/bootstrap@5.2.2/dist/js/bootstrap.bundle.min.js',
					onload: () => {
						this.twitterBootstrapJs.loaded.script = (!!window.bootstrap && typeof window.bootstrap == 'object')
						checkIfAllAreLoaded()
					}
				}
			]
			if (!hasBeenLoaded) {
				injectScripts(scripts)
			}
		})
	}


}

export default new loader