import { injectScripts, checkAllObjectValuesAreTrue } from "../../scriptInjector"

let hasBeenLoaded = false

/**
 * Loads Vue from CDN
 * 
 * Usage:
	import VueLoader from 'hs-dev-helper/js-toolkit/cdnLoaders/vue/vueLoader'
	(async () => await VueLoader.loadVueScripts())()
 */
export const loader = class {

	vue = {
		ready : false,
		loaded: {
			script: false
		}
	}

	loadVueScripts = (onload = null) => { 
		return new Promise((res, rej) => {

			const checkIfAllAreLoaded = () => {
				this.vue.ready = checkAllObjectValuesAreTrue(this.vue.loaded)
				if (this.vue.ready) {
					let payload = {Vue: window.Vue}
					// Fire Event
					var event = new CustomEvent('VueLoaded', { detail : payload });
					window.dispatchEvent(event);
					// OnLoad Callback
					if (this.vue.loaded.script && !!onload && typeof onload == 'function') { 
						onload(payload)
					}
					// Flag
					hasBeenLoaded = true
					// Return Promise
					res(payload)
				}
			}

			//https://v2.vuejs.org/v2/guide/installation.html
			let vueCdnScript = (IS_DEV || false) ?
				'https://cdn.jsdelivr.net/npm/vue@2.7.13/dist/vue.js' :
				'https://cdn.jsdelivr.net/npm/vue@2.7.13/dist/vue.min.js';
			
			let scripts = [
				{
					type: 'script',
					src: vueCdnScript,
					onload: () => {
						this.vue.loaded.script = (!!window.Vue && typeof window.Vue == 'function')
						checkIfAllAreLoaded()
					}
				}
			]
			if (!hasBeenLoaded) {
				injectScripts(scripts)
			}
		})
	}


}

export default new loader